@@ -67,7 +67,7 @@ def commonPreprocess(dataframe):
     return dataframe
 
 def keywordPool(csv):
-    pool = pd.read_csv(csv, sep=',', engine='python', quoting=csv.QUOTE_NONE, encoding='latin-1')
+    pool = pd.read_csv(csv, sep=',', engine='c', encoding='latin-1')
     column = ["brand", "string", "product_name"]
     pool.columns = column
 
@@ -82,7 +82,7 @@ def keywordPool(csv):
     return poolList
 
 def titleSummaryMaker(csv):
-    pool = pd.read_csv(csv, sep=',', engine='python', quoting=csv.QUOTE_NONE, encoding='latin-1')
+    pool = pd.read_csv(csv, sep=',', engine='c', encoding='latin-1')
     column = ["brand", "title_summary_temp", "title_summary"]
     pool.columns = column
 
